@@ -1,7 +1,7 @@
 """Main module fo yamlbase"""
 import sys
+import os
 
-sys.path.append('YamlBase')
 import ybase
 from yamlbase import main
 from .dbworkers import *
